Getting Started — Clyther 0.2.0-beta documentation

### Navigation

- index
- modules |
- next |
- previous |
- Clyther 0.2.0-beta documentation »

# Getting Started

## easy_install

you can just run:

    sudo easy_install clyther

## Prerequisites

- Meta
- OpenCL for Python

## Download

- Stable version from PyPi
- The latest from GitHub

## Build

run:

    python setup.py build
    python setup.py install [ --prefix=$SOMEPATH ]

## Test

run:

    python -m unittest discover clyther/

### Navigation

- index
- modules |
- next |
- previous |
- Clyther 0.2.0-beta documentation »